==> bow-ui-1.1-sources.jar: org/chorem/bow/action/AliasAction.java <==
/*
 * #%L
 * BOW UI
 * 
 * $Id: AliasAction.java 324 2011-08-29 12:21:36Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-1.1/bow-ui/src/main/java/org/chorem/bow/action/AliasAction.java $
 * %%
 * Copyright (C) 2010 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow.action;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.bow.BowBookmark;
import org.nuiton.wikitty.WikittyProxy;
import org.nuiton.wikitty.search.Criteria;
import org.nuiton.wikitty.search.Search;

/**
 * Handles only public aliases. Private aliases are handled by open search.
 *
 * @author poussin
 * @version $Revision: 324 $
 *          <p/>
 *          Last update: $Date: 2011-08-29 14:21:36 +0200 (Mon, 29 Aug 2011) $
 *          by : $Author: tchemit $
 */
public class AliasAction extends BowBaseAction {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    private static final Log log = LogFactory.getLog(AliasAction.class);

    private static final long serialVersionUID = 1L;

    protected String redirectTo = "/";

    protected String alias;

    protected String bookmarkId;

    public String getRedirectTo() {
        return redirectTo;
    }

    public void setAlias(String alias) {
        this.alias = alias;
    }

    public void setBookmarkId(String bookmarkId) {
        this.bookmarkId = bookmarkId;
    }

    @Override
    public String execute() throws Exception {
        if (log.isDebugEnabled()) {
            log.debug("Redirect alias " + alias);
        }
        String result = SUCCESS;
        try {
            if (StringUtils.isNotEmpty(alias)) {
                WikittyProxy proxy = getBowProxy();

                Criteria criteria = Search.query().eq(
                        BowBookmark.FQ_FIELD_BOWBOOKMARK_PUBLICALIAS, alias).criteria();

                BowBookmark bookmark = proxy.findByCriteria(BowBookmark.class, criteria);
                if (bookmark == null) {
                    bookmark = proxy.restore(BowBookmark.class, alias);
                }
                if (bookmark != null) {
                    redirectTo = bookmark.getLink();
                    int clicks = bookmark.getClick() + 1;
                    bookmark.setClick(clicks);
                    proxy.store(bookmark);
                } else {
                    log.error(String.format("No bookmark with alias or id '%s'", alias));
                    addActionError(_("bow.alias.bookmarkId.unknown", alias));
                    result = ERROR;
                }
            }
        } catch (Exception eee) {
            addActionError(_("bow.error.internal"));
            log.error(eee.getMessage(), eee);
            result = ERROR;
        }
        return result;
    }

    public String create() throws Exception {
        String result = SUCCESS;
        try {
            if (!StringUtils.isEmpty(alias)) {
                WikittyProxy proxy = getBowProxy();

                Criteria criteria = Search.query().eq(
                        BowBookmark.FQ_FIELD_BOWBOOKMARK_PUBLICALIAS, alias).criteria();

                BowBookmark bookmark = proxy.findByCriteria(BowBookmark.class, criteria);
                if (bookmark != null) {
                    addActionError(_("bow.alias.already.exists", alias));
                    log.error("A bookmark already exists with alias " + alias);
                    result = ERROR;

                } else {
                    bookmark = proxy.restore(BowBookmark.class, bookmarkId);
                    if (bookmark != null) {
                        bookmark.setPublicAlias(alias);
                        proxy.store(bookmark);
                    } else {
                        addActionError(_("bow.alias.bookmarkId.unknown", bookmarkId));
                        log.debug("No bookmark with id " + bookmarkId);
                        result = ERROR;
                    }
                }
            }
        } catch (Exception eee) {
            addActionError(_("bow.error.internal"));
            log.error(eee.getMessage(), eee);
            result = ERROR;
        }

        return result;
    }

    public String delete() throws Exception {
        log.debug("delete alias for id " + bookmarkId);
        String result = SUCCESS;
        try {
            WikittyProxy proxy = getBowProxy();

            BowBookmark bookmark = proxy.restore(BowBookmark.class, bookmarkId);
            if (bookmark != null) {
                bookmark.setPublicAlias(null);
                proxy.store(bookmark);
            } else {
                addActionError(_("bow.alias.bookmarkId.unknown", bookmarkId));
                log.error("No bookmark with id " + bookmarkId);
                result = ERROR;
            }
        } catch (Exception eee) {
            addActionError(_("bow.error.internal"));
            log.error(eee.getMessage(), eee);
            result = ERROR;
        }

        return result;
    }

}

==> bow-ui-1.2-sources.jar: org/chorem/bow/action/AliasAction.java <==
/*
 * #%L
 * BOW UI
 * 
 * $Id: AliasAction.java 360 2013-09-24 17:54:39Z bpoussin $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-1.2/bow-ui/src/main/java/org/chorem/bow/action/AliasAction.java $
 * %%
 * Copyright (C) 2010 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow.action;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.bow.BowBookmark;
import org.chorem.bow.BowProxy;
import org.chorem.bow.BowUser;
import org.nuiton.wikitty.query.WikittyQuery;
import org.nuiton.wikitty.query.WikittyQueryMaker;

/**
 * Handles only public aliases. Private aliases are handled by open search.
 *
 * @author poussin
 * @version $Revision: 360 $
 *          <p/>
 *          Last update: $Date: 2013-09-24 19:54:39 +0200 (Tue, 24 Sep 2013) $
 *          by : $Author: bpoussin $
 */
public class AliasAction extends BowBaseAction {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    private static final Log log = LogFactory.getLog(AliasAction.class);

    private static final long serialVersionUID = 1L;

    protected String redirectTo = "/";

    protected String alias;

    protected String bookmarkId;

    public String getRedirectTo() {
        return redirectTo;
    }

    public void setAlias(String alias) {
        this.alias = alias;
    }

    public void setBookmarkId(String bookmarkId) {
        this.bookmarkId = bookmarkId;
    }

    @Override
    public String execute() throws Exception {
        if (log.isDebugEnabled()) {
            log.debug("Redirect alias " + alias);
        }
        String result = SUCCESS;
        try {
            if (StringUtils.isNotEmpty(alias)) {
                BowProxy proxy = getBowProxy();

                WikittyQuery criteria = new WikittyQueryMaker().or()
                        .ideq(alias)
                        .eq(BowBookmark.FQ_FIELD_BOWBOOKMARK_PUBLICALIAS, alias)
                        .end();

                BowBookmark bookmark = proxy.findByQuery(BowBookmark.class, criteria);
                if (bookmark == null) {
                    // not id or public alias, looking for private if user is logged
                    BowUser user = getBowSession().getUser();
                    if (user != null) {
                        criteria = new WikittyQueryMaker().and()
                                .eq(BowBookmark.FQ_FIELD_WIKITTYAUTHORISATION_OWNER, user.getWikittyId())
                                .eq(BowBookmark.FQ_FIELD_BOWBOOKMARK_PRIVATEALIAS, alias)
                                .end();
                        bookmark = proxy.findByQuery(BowBookmark.class, criteria);
                    }
                }
                if (bookmark != null) {
                    redirectTo = bookmark.getLink();
                    int clicks = bookmark.getClick() + 1;
                    bookmark.setClick(clicks);
                    proxy.store(bookmark);
                } else {
                    log.error(String.format("No bookmark with alias or id '%s'", alias));
                    addActionError(_("bow.alias.bookmarkId.unknown", alias));
                    result = ERROR;
                }
            }
        } catch (Exception eee) {
            addActionError(_("bow.error.internal"));
            log.error(eee.getMessage(), eee);
            result = ERROR;
        }
        return result;
    }

    public String create() throws Exception {
        String result = SUCCESS;
        try {
            if (!StringUtils.isEmpty(alias)) {
                BowProxy proxy = getBowProxy();

                WikittyQuery criteria = new WikittyQueryMaker().eq(
                        BowBookmark.FQ_FIELD_BOWBOOKMARK_PUBLICALIAS, alias).end();

                BowBookmark bookmark = proxy.findByQuery(BowBookmark.class, criteria);
                if (bookmark != null) {
                    addActionError(_("bow.alias.already.exists", alias));
                    log.error("A bookmark already exists with alias " + alias);
                    result = ERROR;

                } else {
                    bookmark = proxy.restore(BowBookmark.class, bookmarkId);
                    if (bookmark != null) {
                        bookmark.setPublicAlias(alias);
                        proxy.store(bookmark);
                    } else {
                        addActionError(_("bow.alias.bookmarkId.unknown", bookmarkId));
                        log.debug("No bookmark with id " + bookmarkId);
                        result = ERROR;
                    }
                }
            }
        } catch (Exception eee) {
            addActionError(_("bow.error.internal"));
            log.error(eee.getMessage(), eee);
            result = ERROR;
        }

        return result;
    }

    public String delete() throws Exception {
        log.debug("delete alias for id " + bookmarkId);
        String result = SUCCESS;
        try {
            BowProxy proxy = getBowProxy();

            BowBookmark bookmark = proxy.restore(BowBookmark.class, bookmarkId);
            if (bookmark != null) {
                bookmark.setPublicAlias(null);
                proxy.store(bookmark);
            } else {
                addActionError(_("bow.alias.bookmarkId.unknown", bookmarkId));
                log.error("No bookmark with id " + bookmarkId);
                result = ERROR;
            }
        } catch (Exception eee) {
            addActionError(_("bow.error.internal"));
            log.error(eee.getMessage(), eee);
            result = ERROR;
        }

        return result;
    }

}
